/**
 * EffectsConstants.java $Revision: 417 $ $Date: 2007-10-31 00:50:11 +0100 (Wed, 31 Oct 2007) $
 *
 * Copyright ${year} jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.naming;

import org.apache.xerces.impl.xpath.regex.RegularExpression;

/**
 * Includes all the constants related to the Effects tags. These 
 * constants refer both to the attribute names and their valid values
 * 
 * @author sschz@users.sourceforge.net
 * @since 1.0
 * 
 */
public class EffectsConstants {
	
	public static final String TRANSITION = "transition";
	
	public static final String DURATION = "duration";
	
	public static final String DIRECTION = "direction";
	
	public static final String DELAY = "delay";
		
	public static final String SCALE_MODE = "scaleMode";
	
	public static final String SCALE_FROM = "scaleFrom";
	
	public static final String SCALE_TO = "scaleTo";
	
	public static final String FPS = "fps";
	
	public static final String TYPE = "type";
	
	public static final String FROM = "from";
	
	public static final String EFFECT = "effect";
	
	public static final String TO = "to";
	
	public static final String START_COLOR = "startColor";
	
	public static final String END_COLOR = "endColor";
	
	public static final String RESTORE_COLOR = "restoreColor";

	public static final String PULSES = "pulses";

	public static String SHOOTERS_SELECTOR = "shootersSelector";
	
	public static String EVENT = "event";
	
	public static String CORNERS = "corners";
	
	public static String COLOR = "color";
	public static String COLOR_FROM_ELEMENT = "fromElement";
	
	public static String BG_COLOR = "bgColor";
	public static String BG_COLOR_FROM_PARENT = "fromParent";
	
	public static String BORDER_COLOR = "border";
	
	public static String APPEAR_EFFECT = "appear";
	
	public static String TABS_IDS = "tabsIds";
	
	public static String TABS_CONTENT_IDS = "tabsContentIds";
	
	/**
	 * Valid values for the transition tag attribute
	 */
	public static final String[] VALID_TRANSITIONS = {"MochiKit.Visual.Transitions.linear",
		  "MochiKit.Visual.Transitions.sinoidal", "MochiKit.Visual.Transitions.reverse", 
		  "MochiKit.Visual.Transitions.flicker",
		  "MochiKit.Visual.Transitions.wobble", "MochiKit.Visual.Transitions.pulse",
		  "MochiKit.Visual.Transitions.none", "MochiKit.Visual.Transitions.full"};

	/**
	 * Valid values for the Blind effect direction tag attribute
	 */
	public static final String[] BLIND_VALID_DIRECTIONS = {"Up", "Down"};
	
	/**
	 * Valid values for the Blind effect scale mode attribute
	 */
	public static final String[] BLIND_VALID_SCALE_MODES = {"box", "contents"};

	/**
	 * Valid values for the Grow effect direction attribute
	 */
	public static final String[] GROW_VALID_DIRECTIONS = {"top-left", "top-right", "bottom-left", "bottom-right", "center"};
	
	/**
	 * Valid values for the Slide effect direction attribute
	 */
	public static final String[] SLIDE_VALID_DIRECTIONS = {"Up", "Down"};
	
	/**
	 * Valid values for the Slide effect scale mode attribute
	 */
	public static final String[] SLIDE_VALID_SCALE_MODES = {"box", "contents"};

	/**
	 * Valid values for the Toggle effect attribute
	 */
	public static final String[] TOGGLE_VALID_EFFECTS = {"appear", "blind", "size", "slide"};
	
	/**
	 * Valid values for the Simple Effect type attribute
	 */
	public static final String[] SIMPLE_EFFECT_VALID_TYPES = {"appear", "fade", "puff", "dropOut",
		"shake", "switchOff", "squish", "fold", "shrink", "Opacity"};
	
	/**
	 * Valid values for the corners attribute of the round effect
	 */
	public static final String[] CORNERS_VALID_DIRECTIONS = {"all", "top", "bottom", "tl", "bl", "tr", "br"};
	
	
	/**
	 * Valid values for the tabs content effect (multiple-tab tag)
	 */
	public static final String[] MULTIPLE_TAB_EFFECT_VALID_TYPES = {"appear", "blindDown", "slideDown"};
	
	public static final RegularExpression colorRegExp = new RegularExpression("(^#([A-F|a-f|0-9]){3}$)|(^#([A-F|a-f|0-9]){6}$)");
	
}
