/**
 * AsyncContentLoader.java $Revision: 417 $ $Date: 2007-10-31 00:50:11 +0100 (Wed, 31 Oct 2007) $
 *
 * Copyright 2007 jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.content;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.jsp.JspException;

import net.sf.json.JSONFunction;
import net.sf.json.JSONObject;
import net.sourceforge.jstags.naming.TemplateConstants;
import net.sourceforge.jstags.tags.JSTagsTagSupport;

import org.apache.commons.lang.StringUtils;

/**
 * It loads some content asynchronously in the page when it is loaded.
 * 
 * @author sschz@users.sourceforge.net
 * @since 1.1
 */
public class AsyncContentLoader extends JSTagsTagSupport {

	private static final long serialVersionUID = -6924922000797299824L;

	//TODO add possibility to load data when an event occurs
	
	private String url;
	
	private String nameValuePairs;
	
	private String contentType;
	
	private String targetId;
	
	private String callbackFc;
	
	/* (non-Javadoc)
	 * @see net.sourceforge.jstags.tags.JSTagsBodyTagSupport#getTemplateName()
	 */
	@Override
	protected String getTemplateName() throws JspException {
		return TemplateConstants.ASYNC_CONTENT_LOADER_TEMPLATE_NAME;
	}

	/* (non-Javadoc)
	 * @see net.sourceforge.jstags.tags.JSTagsBodyTagSupport#getTemplateNameValuePairs()
	 */
	@Override
	protected Map<String, String> getTemplateNameValuePairs() {
		
		Map<String, String> map = new HashMap<String, String>();
		
		JSONObject jObject = new JSONObject();
		jObject.put(TemplateConstants.URL_PARAM_NAME, getUrl());
		jObject.put(TemplateConstants.NAME_VALUE_PAIRS_PARAM_NAME, 
				(StringUtils.isEmpty(getNameValuePairs()) ? "{}" : getNameValuePairs()));
		jObject.put(TemplateConstants.CONTENT_TYPE_PARAM_NAME, getContentType());
		jObject.put(TemplateConstants.TARGET_ID_PARAM_NAME, getTargetId());
		
		JSONFunction jsf = new JSONFunction(new String[] {"request", "targetId"}, getCallbackFc() + "(request, targetId);");

		jObject.put(TemplateConstants.CALLBACK_FUNCTION_NAME_PARAM_NAME, jsf);
		
		
		map.put(TemplateConstants.PARAMETERS_VAR_NAME, jObject.toString(TemplateConstants.INDENT_FACTOR));			
		return map;
	}

	/**
	 * @return URL the content is loaded from.
	 */
	public String getUrl() {
		return url;
	}

	public void setUrl(String url) {
		this.url = url;
	}

	/**
	 * @return It contains a ',' separated object of pairs name:value. 
	 * i.e. {name1:'value1',name2:56}. These parameters will be added, with the value 
	 * given here, to the request
	 */
	public String getNameValuePairs() {
		return nameValuePairs;
	}

	public void setNameValuePairs (String nameValuePairs) {
		this.nameValuePairs = nameValuePairs;
	}

	/**
	 * @return Type of the content being loaded. If HTML it will be inserted in the 
	 * targetId element automatically. Otherwise, a js function must be provided 
	 * to insert such content.
	 */
	public String getContentType() {
		return contentType;
	}

	public void setContentType(String contentType) {
		this.contentType = contentType;
	}

	/**
	 * @return Identifier of the element the content retrieved from the URL 
	 * will be inserted in.
	 */
	public String getTargetId() {
		return targetId;
	}

	public void setTargetId(String targetId) {
		this.targetId = targetId;
	}

	/**
	 * @return JavaScript function being executed when the content is fetched 
	 * from the given URL. It inserts such content in the page.
	 */
	public String getCallbackFc() {
		return callbackFc;
	}

	public void setCallbackFc(String callbackFc) {
		this.callbackFc = callbackFc;
	}

}
