/**
 * AsyncContentLoaderValidator.java $Revision: 358 $ $Date: 2007-10-23 00:41:49 +0200 (Tue, 23 Oct 2007) $
 *
 * Copyright 2007 jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.content;

import java.util.ArrayList;
import java.util.Collection;

import javax.servlet.jsp.tagext.TagData;
import javax.servlet.jsp.tagext.TagExtraInfo;
import javax.servlet.jsp.tagext.ValidationMessage;

import net.sf.json.util.JSONUtils;
import net.sourceforge.jstags.naming.ContentConstants;
import net.sourceforge.jstags.utils.validation.TagsUtils;

import org.apache.commons.lang.ArrayUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;

/**
 * @author sschz@users.sourceforge.net
 * @since 1.1
 */
public class AsyncContentLoaderValidator extends TagExtraInfo {

	/**
	 * Logger for this class
	 */
	private static final Logger logger = Logger
			.getLogger(AsyncContentLoaderValidator.class);


	/* (non-Javadoc)
	 * @see javax.servlet.jsp.tagext.TagExtraInfo#validate(javax.servlet.jsp.tagext.TagData)
	 */
	public ValidationMessage[] validate(TagData data) {

		Collection<ValidationMessage> messages = new ArrayList<ValidationMessage>();

		Object nameValuePairs = data.getAttribute(ContentConstants.NAME_VALUE_PAIRS_TAG_ATTR_NAME);
		Object contentType = data.getAttribute(ContentConstants.CONTENT_TYPE_TAG_ATTR_NAME);
		Object callbackFc = data.getAttribute(ContentConstants.CALLBACK_FUNCTION_TAG_ATTR_NAME);
					
		// nameValuePairs must be a JavaScript object 
		if (TagsUtils.isValueAvailableAtTranslationTime(nameValuePairs)) {
			if ((!JSONUtils.mayBeJSON((String)nameValuePairs))
					|| (JSONUtils.mayBeJSON((String)nameValuePairs) && !((String)nameValuePairs).startsWith("{"))){
				logger.error("Param 'nameValuePairs: " + (String)nameValuePairs 
						+ "' must be a String representing a valid JSON Object");
				messages.add(new ValidationMessage(data.getId(), 
						"Param 'nameValuePairs: " + (String)nameValuePairs 
						+ "' must be a String representing a valid JSON Object"));
			}
		}
			
		// contentType must have one of the valid values 
		if (TagsUtils.isValueAvailableAtTranslationTime(contentType)			
			&& (!ArrayUtils.contains(ContentConstants.CONTENT_TYPE_VALID_VALUES, (String)contentType))){
			logger.error("Param 'contentType: " + (String)contentType + "' is not in the valid values " 
					+ ArrayUtils.toString(ContentConstants.CONTENT_TYPE_VALID_VALUES));
			messages.add(new ValidationMessage(data.getId(), 
					"Param 'contentType: " + (String)contentType + "' is not in the valid values " 
					+ ArrayUtils.toString(ContentConstants.CONTENT_TYPE_VALID_VALUES)));
		}
		
		// if contentType is set, callbackFc must be set as well
		if (TagsUtils.isValueAvailableAtTranslationTime(contentType)) {
			if ((StringUtils.equals(ContentConstants.CONTENT_TYPE_OTHER, (String)contentType))
					&& (StringUtils.isEmpty((String)callbackFc))){
				logger.error("Param 'callbackFc must be set as contentType is 'other'");
				messages.add(new ValidationMessage(data.getId(), 
						"Param 'callbackFc must be set as contentType is 'other'"));
			}
		}
		
		return (ValidationMessage[])messages.toArray(new ValidationMessage[messages.size()]);
	}
}
