/**
 * Blind.java $Revision: 417 $ $Date: 2007-10-31 00:50:11 +0100 (Wed, 31 Oct 2007) $
 *
 * Copyright 2007 jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.effects;

import java.util.Map;

import javax.servlet.jsp.JspException;

import net.sf.json.JSONObject;
import net.sourceforge.jstags.naming.TemplateConstants;

import org.apache.commons.lang.StringUtils;

/**
 * It simulates a window blind, where the contents of the affected elements
 * stay in place. 
 * 
 * This effect depends on the JavaScript library 
 * <a HREF="http://mochikit.com">Mochikit</a> 
 *
 * @author sschz@users.sourceforge.net
 * @since 1.0
 * 
 */
public class Blind extends Effect {
	
	private static final long serialVersionUID = 3225680038297719944L;

	private String direction;
	
	private Boolean scaleX;
	private Boolean scaleY;
	private Boolean scaleContent;
	private String scaleMode;
	private String scaleFrom;
	private String scaleTo;
	
	/**
	 * @return how the element will appear on the page. Valid values are 
	 * Up(from top to bottom) and Down(from bottom to top)
	 */
	public String getDirection() {
		return direction;
	}
	
	/**
	 * @param direction how the element will appear on the page. Valid values are 
	 * Up(from top to bottom) and Down(from bottom to top)
	 */
	public void setDirection(String direction) {
		this.direction = direction;
	}

	/**
	 * @return Whether the element's content should be modified 
	 * during the effect or not. Default value is true
	 */
	public Boolean getScaleContent() {
		return scaleContent;
	}

	/**
	 * @param scaleContent Whether the element's content should 
	 * be modified during the effect or not. Default value is true
	 */
	public void setScaleContent(Boolean scaleContent) {
		this.scaleContent = scaleContent;
	}

	/**
	 * @return Percentage of the element size the transition will start at
	 */
	public String getScaleFrom() {
		return scaleFrom;
	}

	/**
	 * @param scaleFrom Percentage of the element size the transition will start at
	 */
	public void setScaleFrom(String scaleFrom) {
		this.scaleFrom = scaleFrom;
	}

	/**
	 * @return How the scale is done. Valid values are box (default one, 
	 * it scales the visible area of the element) and contents (scales 
	 * the complete element, that is, it takes into account parts normally
	 * only visible by scrolling).
	 */
	public String getScaleMode() {
		return scaleMode;
	}

	/**
	 * @param scaleMode How the scale is done. Valid values are box 
	 * (default one, it scales the visible area of the element) and 
	 * contents (scales the complete element, that is, it takes into 
	 * account parts normally only visible by scrolling).
	 */
	public void setScaleMode(String scaleMode) {
		this.scaleMode = scaleMode;
	}

	/**
	 * @return Percentage of the element size the transition will end at
	 */
	public String getScaleTo() {
		return scaleTo;
	}

	/**
	 * @param scaleTo Percentage of the element size the transition will end at
	 */
	public void setScaleTo(String scaleTo) {
		this.scaleTo = scaleTo;
	}

	/**
	 * @return Whether the element's width changes or not during the effect.
	 * Default value is false
	 */
	public Boolean getScaleX() {
		return scaleX;
	}

	/**
	 * @param scaleX Whether the element's width changes or not during the effect.
	 * Default value is false
	 */
	public void setScaleX(Boolean scaleX) {
		this.scaleX = scaleX;
	}

	/**
	 * @return Whether the element's width should change or not. 
	 * Default value is true
	 */
	public Boolean getScaleY() {
		return scaleY;
	}

	/**
	 * @param scaleY Whether the element's width should change or not. 
	 * Default value is true
	 */
	public void setScaleY(Boolean scaleY) {
		this.scaleY = scaleY;
	}

	/* (non-JavaDoc)
	 * @see org.jstags.utils.tags.JSTagsTagSupport#getTemplateName()
	 */
	protected String getTemplateName() throws JspException {		
		return TemplateConstants.BLIND_TEMPLATE_NAME;
	}
		
	/* (non-JavaDoc)
	 * @see org.jstags.tags.effects.Effect#getTemplateNameValuePairs()
	 */
	protected Map<String, String> getTemplateNameValuePairs() {

		Map<String, String> map = super.getTemplateNameValuePairs();
		
		JSONObject jsObject = JSONObject.fromString(map.get(TemplateConstants.PARAMETERS_VAR_NAME));		
		jsObject.put(TemplateConstants.OPTIONS_PARAM_NAME, getOptions());
		jsObject.put(TemplateConstants.EFFECT_PARAM_NAME, "blind" + getDirection());
		
		map.put(TemplateConstants.PARAMETERS_VAR_NAME, jsObject.toString(TemplateConstants.INDENT_FACTOR));
		return map;
	}
	
	/* (non-JavaDoc)
	 * @see org.ajaxlib.tags.effects.Effect#getOptions()
	 */
	protected JSONObject getOptions() {
		JSONObject options = super.getOptions();
				
		if (scaleX != null) {
			options.put("scaleX", new Boolean(scaleX));			
		}
		if (scaleY != null) {
			options.put("scaleY", new Boolean(scaleY));
		}
		if (scaleContent != null) {
			options.put("scaleContent", new Boolean(scaleContent));			
		}
		if (!StringUtils.isEmpty(scaleMode)) {
			options.put("scaleMode", scaleMode);			
		}
		if (!StringUtils.isEmpty(scaleFrom)) {
			options.put("scaleFrom", new Float(scaleFrom));			
		}
		if (!StringUtils.isEmpty(scaleTo)) {
			options.put("scaleTo", new Float(scaleTo));			
		}
				
		return options;
	}
}

