/**
 * EffectValidator.java $Revision: 206 $ $Date: 2007-10-12 15:04:38 +0200 (Fri, 12 Oct 2007) $
 *
 * Copyright 2007 jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.effects;

import java.util.ArrayList;
import java.util.Collection;

import javax.servlet.jsp.tagext.TagData;
import javax.servlet.jsp.tagext.TagExtraInfo;
import javax.servlet.jsp.tagext.ValidationMessage;

import net.sourceforge.jstags.naming.EffectsConstants;
import net.sourceforge.jstags.utils.validation.NumberUtils;
import net.sourceforge.jstags.utils.validation.TagsUtils;

import org.apache.commons.lang.ArrayUtils;
import org.apache.log4j.Logger;

/**
 * It performs the validation of the effects common data 
 *
 * @author sschz@users.sourceforge.net
 * @since 1.0
 * 
 */
public class EffectValidator extends TagExtraInfo {
	/**
	 * Logger for this class
	 */
	private static final Logger logger = Logger
			.getLogger(EffectValidator.class);

	/* (non-Javadoc)
	 * @see javax.servlet.jsp.tagext.TagExtraInfo#validate(javax.servlet.jsp.tagext.TagData)
	 */
	public ValidationMessage[] validate(TagData data) {

		Collection<ValidationMessage> messages = new ArrayList<ValidationMessage>();

		//TODO validate queue by means of a regular expression
		
		Object transition = data.getAttribute(EffectsConstants.TRANSITION);
		Object duration = data.getAttribute(EffectsConstants.DURATION);
		Object delay = data.getAttribute(EffectsConstants.DELAY);
		Object fps = data.getAttribute(EffectsConstants.FPS);
		Object from = data.getAttribute(EffectsConstants.FROM);
		Object to = data.getAttribute(EffectsConstants.TO);
		Object shootersSelector = data.getAttribute(EffectsConstants.SHOOTERS_SELECTOR);
		Object event = data.getAttribute(EffectsConstants.EVENT);
		
		// Check that the transition value is included in the valid transitions
		if (TagsUtils.isValueAvailableAtTranslationTime(transition)
			&& (!ArrayUtils.contains(EffectsConstants.VALID_TRANSITIONS, (String)transition))){
			logger.error("Param 'transition: " + (String)transition + "' is not in the valid values");
			messages.add(new ValidationMessage(data.getId(), 
					"Param 'transition: " + (String)transition + "' is not in the valid values"));
		}
		
		// Duration must be a float
		if (TagsUtils.isValueAvailableAtTranslationTime(duration)) {
			if (!NumberUtils.isFloat((String)duration)) {				
				logger.error("Param 'duration: " + (String)duration + "' must be a float");
				messages.add(new ValidationMessage(data.getId(), 
						"Param 'duration: " + (String)duration + "' must be a float"));
			}	
		}
		
		// From must be a float
		if (TagsUtils.isValueAvailableAtTranslationTime(from)) {
			if (!NumberUtils.isFloat((String)from)) {			
				logger.error("Param 'from: " + (String)from + "' must be a float");
				messages.add(new ValidationMessage(data.getId(), 
						"Param 'from: " + (String)from + "' must be a float"));
			}	
		}
		
		// To must be a float
		if (TagsUtils.isValueAvailableAtTranslationTime(to)) {
			if (!NumberUtils.isFloat((String)to)) {			
				logger.error("Param 'to: " + (String)to + "' must be a float");
				messages.add(new ValidationMessage(data.getId(), 
						"Param 'to: " + (String)to + "' must be a float"));
			}	
		}
		
		// Frames per second must be a float
		if (TagsUtils.isValueAvailableAtTranslationTime(fps)) {
			if (!NumberUtils.isFloat((String)fps)) {
				logger.error("Param 'fps: " + (String)fps + "' must be a float");
				messages.add(new ValidationMessage(data.getId(), 
						"Param 'fps: " + (String)fps + "' must be a float"));
			}	
		}	
		
		// Delay must be a float
		if (TagsUtils.isValueAvailableAtTranslationTime(delay)) {
			if (!NumberUtils.isFloat((String)delay)) {			
				logger.error("Param 'delay: " + (String)delay + "' must be a float");
				messages.add(new ValidationMessage(data.getId(), 
						"Param 'from: " + (String)delay + "' must be a float"));
			}	
		}
		
		if ((shootersSelector != null) || (event != null)) {
			if ((shootersSelector == null) || (event == null)) {
				logger.error("Params 'shootersSelector' and 'event' must be set either both or none");
				messages.add(new ValidationMessage(data.getId(), 
						"Params 'shootersSelector' and 'event' must be set either both or none"));
			}
		}
		
		return (ValidationMessage[])messages.toArray(new ValidationMessage[messages.size()]);
	}
	
}
