/**
 * GrowValidator.java $Revision: 206 $ $Date: 2007-10-12 15:04:38 +0200 (Fri, 12 Oct 2007) $
 *
 * Copyright 2007 jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.effects;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;

import javax.servlet.jsp.tagext.TagData;
import javax.servlet.jsp.tagext.ValidationMessage;

import net.sourceforge.jstags.naming.EffectsConstants;
import net.sourceforge.jstags.utils.validation.TagsUtils;

import org.apache.commons.lang.ArrayUtils;
import org.apache.log4j.Logger;

/**
 * It performs the validation of the {@link Grow} tag
 * 
 * @author sschz@users.sourceforge.net
 * @since 1.0
 * 
 */
public class GrowValidator extends EffectValidator {
	/**
	 * Logger for this class
	 */
	private static final Logger logger = Logger.getLogger(GrowValidator.class);


	/* (non-Javadoc)
	 * @see org.jstags.tags.effects.EffectValidator#validate(javax.servlet.jsp.tagext.TagData)
	 */
	public ValidationMessage[] validate(TagData data) {
		
		Collection<ValidationMessage> messages = new ArrayList<ValidationMessage>();
		messages.addAll(Arrays.asList(super.validate(data)));
		
		Object direction = data.getAttribute(EffectsConstants.DIRECTION);
		
		// Check that the direction value is included in the valid ones for the effect
		if (TagsUtils.isValueAvailableAtTranslationTime(direction)
			&& (!ArrayUtils.contains(EffectsConstants.GROW_VALID_DIRECTIONS, (String)direction))){
			logger.error("Param 'direction: " + (String)direction + "' is not in the valid values " 
					+ ArrayUtils.toString(EffectsConstants.GROW_VALID_DIRECTIONS));
			messages.add(new ValidationMessage(data.getId(), 
					"Param 'direction: " + (String)direction + "' is not in the valid values " 
					+ ArrayUtils.toString(EffectsConstants.GROW_VALID_DIRECTIONS)));
		}
		
		
		return (ValidationMessage[])messages.toArray(new ValidationMessage[messages.size()]);
		
	}
}

