/**
 * Highlight.java $$Revision: 417 $ $Date: 2007-10-31 00:50:11 +0100 (Wed, 31 Oct 2007) $
 *
 * Copyright 2007 jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.effects;

import java.util.Map;

import javax.servlet.jsp.JspException;

import net.sf.json.JSONObject;
import net.sourceforge.jstags.naming.TemplateConstants;

import org.apache.commons.lang.StringUtils;

/**
 * It Flashes a color as the background of an element
 * 
 * This effect depends on the javascript library 
 * <a href="http://mochikit.com/">Mochikit</a> 
 *
 * @author sschz@users.sourceforge.net
 * @since 1.0
 * 
 */
public class Highlight extends Effect {
	
	private static final long serialVersionUID = 3225680038297719944L;

	private String startColor;
		
	
	/**
	 * @return Color the element will have when the effect starts. i.e. #ff0023
	 */
	public String getStartColor() {
		return startColor;
	}

	/**
	 * @param startColor Color the element will have when the effect starts. i.e. #ff0023
	 */
	public void setStartColor(String startColor) {
		this.startColor = startColor;
	}

	/* (non-Javadoc)
	 * @see org.jstags.utils.tags.JSTagsTagSupport#getTemplateName()
	 */
	protected String getTemplateName() throws JspException {		
		return TemplateConstants.HIGHLIGHT_TEMPLATE_NAME;
	}
	
	@Override
	protected Map<String, String> getTemplateNameValuePairs() {
		Map<String, String> map = super.getTemplateNameValuePairs();
		
		JSONObject jsObject = JSONObject.fromString(map.get(TemplateConstants.PARAMETERS_VAR_NAME));		
		jsObject.put(TemplateConstants.EFFECT_PARAM_NAME, "Highlight");
		
		map.put(TemplateConstants.PARAMETERS_VAR_NAME, jsObject.toString(TemplateConstants.INDENT_FACTOR));
		return map;
	}
	
	/* (non-Javadoc)
	 * @see org.ajaxlib.tags.effects.Effect#getOptions()
	 */
	protected JSONObject getOptions() {
		JSONObject options = super.getOptions();
			
		if (!StringUtils.isEmpty(startColor)) {
			options.put("startcolor", startColor);			
		}
		
		return options;
	}

}
