/**
 * HighlightValidator.java $Revision: 243 $ $Date: 2007-10-13 13:16:50 +0200 (Sat, 13 Oct 2007) $
 *
 * Copyright 2007 jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.effects;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;

import javax.servlet.jsp.tagext.TagData;
import javax.servlet.jsp.tagext.ValidationMessage;

import net.sourceforge.jstags.naming.EffectsConstants;
import net.sourceforge.jstags.utils.validation.TagsUtils;

import org.apache.log4j.Logger;
import org.apache.xerces.impl.xpath.regex.RegularExpression;

/**
 * It performs the validation of the {@link Highlight} effect parameters
 * 
 * @author sschz@users.sourceforge.net
 * @since 1.0
 * 
 */
public class HighlightValidator extends EffectValidator {
	
	/**
	 * Logger for this class
	 */
	private static final Logger logger = Logger
			.getLogger(HighlightValidator.class);

	
	/* (non-Javadoc)
	 * @see org.jstags.tags.effects.EffectValidator#validate(javax.servlet.jsp.tagext.TagData)
	 */
	public ValidationMessage[] validate(TagData data) {
		
		Collection<ValidationMessage> messages = new ArrayList<ValidationMessage>();
		messages.addAll(Arrays.asList(super.validate(data)));
		
		Object startColor = data.getAttribute(EffectsConstants.START_COLOR);
		
		RegularExpression colorRegExp = new RegularExpression("(^#([A-F|a-f|0-9]){3}$)|(^#([A-F|a-f|0-9]){6}$)");
		
		// Check that the startColor is valid
		if (TagsUtils.isValueAvailableAtTranslationTime(startColor)) {
			if (!colorRegExp.matches((String)startColor)) {
				logger.error("Param 'startColor: " + (String)startColor 
						+ "' must match regular expression " + colorRegExp.getPattern());
				messages.add(new ValidationMessage(data.getId(), 
						"Param 'startColor: " + (String)startColor 
						+ "' must match regular expression " + colorRegExp.getPattern()));
			}
		}
				
		return (ValidationMessage[])messages.toArray(new ValidationMessage[messages.size()]);
		
	}	
	
}
