/**
 * MultipleTab.java $Revision: 417 $ $Date: 2007-10-31 00:50:11 +0100 (Wed, 31 Oct 2007) $
 *
 * Copyright 2007 jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.effects;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.jsp.JspException;

import org.apache.commons.lang.StringUtils;

import net.sf.json.JSONObject;
import net.sourceforge.jstags.naming.EffectsConstants;
import net.sourceforge.jstags.naming.TemplateConstants;
import net.sourceforge.jstags.tags.JSTagsTagSupport;

/**
 * It configures a set of elements to act as a kind of accordion. There are some elements
 * that behave as tabs and, some others that act as tabs content. Every tab element has a
 * tab content element so that, when one of the tabs is clicked, the corresponding tab content
 * is displayed and any other becomes hidden.
 * 
 * This effect depends on the javascript library 
 * <a href="http://mochikit.com/">Mochikit</a> 
 *     
 * @author sschz@users.sourceforge.net
 * @since 1.1
 */
public class MultipleTab extends JSTagsTagSupport {

	private static final long serialVersionUID = 3455932562222950563L;

	private String selectedTabClass;
	
	private String selectedTabId;
	
	private String tabsIds;
	
	private String tabsContentIds;
	
	private String effect;
	
	private String duration;
	
	/* (non-Javadoc)
	 * @see net.sourceforge.jstags.tags.JSTagsTagSupport#getTemplateName()
	 */
	@Override
	protected String getTemplateName() throws JspException {
		return TemplateConstants.MULTIPLE_TAB_TEMPLATE_NAME;
	}

	/* (non-Javadoc)
	 * @see net.sourceforge.jstags.tags.JSTagsTagSupport#getTemplateNameValuePairs()
	 */
	@Override
	protected Map<String, String> getTemplateNameValuePairs() {
		
		Map<String, String> map = new HashMap<String, String>();
		
		map.put(TemplateConstants.TABS_CONTENT_IDS_VAR_NAME, getTabsContentIds());
		map.put(TemplateConstants.TABS_IDS_VAR_NAME, getTabsIds());
		 
		JSONObject jsObject = new JSONObject();
		jsObject.put(TemplateConstants.SELECTED_TAB_CLASS_PARAM_NAME, getSelectedTabClass());
		jsObject.put(TemplateConstants.EFFECT_PARAM_NAME, (StringUtils.isEmpty(getEffect()) ? EffectsConstants.APPEAR_EFFECT : getEffect()));
		jsObject.put(TemplateConstants.DURATION_PARAM_NAME, (StringUtils.isEmpty(getDuration())) ? 0 : getDuration());
		jsObject.put(TemplateConstants.SELECTED_TAB_ID_PARAM_NAME, getSelectedTabId());
		
		map.put(TemplateConstants.TABS_PARAMS_VAR_NAME, jsObject.toString(TemplateConstants.INDENT_FACTOR));
		
		return map;
	}

	/**
	 * @return Identifier of the tab that will be selected initially. The tab content 
	 * related to it, will be displayed when the page is loaded. If not set, no tab 
	 * content will be displayed.
	 */
	public String getSelectedTabId() {
		return selectedTabId;
	}

	public void setSelectedTabId(String selectedTabId) {
		this.selectedTabId = selectedTabId;
	}

	
	/**
	 * @return Identifiers of the tabs. The ones that will be visible always and,
	 * depending on the one clicked by the user, will show a different tab 
	 * content element.
	 */
	public String getTabsIds() {
		return tabsIds;
	}

	public void setTabsIds(String tabsIds) {
		this.tabsIds = tabsIds;
	}

	/**
	 * @return Identifiers of the tabs content. Only one tab content is shown at 
	 * one time. Such an element will depend on the clicked shooterId element
	 */
	public String getTabsContentIds() {
		return tabsContentIds;
	}

	public void setTabsContentIds(String tabsContentIds) {
		this.tabsContentIds = tabsContentIds;
	}

	/**
	 * @return CSS class of the tab that is selected currently
	 */
	public String getSelectedTabClass() {
		return selectedTabClass;
	}

	public void setSelectedTabClass(String selectedTabClass) {
		this.selectedTabClass = selectedTabClass;
	}

	/**
	 * @return The kind of effect being fired on the tab content to display it when a tab 
        is clicked. 
	 */
	public String getEffect() {
		return effect;
	}

	public void setEffect(String effect) {
		this.effect = effect;
	}

	/**
	 * @return Duration of the effect being performed whenever a tab is clicked and 
	 * its content shown. It's the effect that will be fired on the tab content. 
	 * It's a float representing the number of seconds. 
	 */
	public String getDuration() {
		return duration;
	}

	public void setDuration(String duration) {
		this.duration = duration;
	}

}
