/**
 * MultipleTabValidator.java $Revision: 417 $ $Date: 2007-10-31 00:50:11 +0100 (Wed, 31 Oct 2007) $
 *
 * Copyright 2007 jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.effects;

import java.util.ArrayList;
import java.util.Collection;

import javax.servlet.jsp.tagext.TagData;
import javax.servlet.jsp.tagext.TagExtraInfo;
import javax.servlet.jsp.tagext.ValidationMessage;

import net.sf.json.util.JSONUtils;
import net.sourceforge.jstags.naming.EffectsConstants;
import net.sourceforge.jstags.utils.validation.NumberUtils;
import net.sourceforge.jstags.utils.validation.TagsUtils;

import org.apache.commons.lang.ArrayUtils;
import org.apache.log4j.Logger;

/**
 * @author sschz@users.sourceforge.net
 * @since 1.1
 */
public class MultipleTabValidator extends TagExtraInfo {

	/**
	 * Logger for this class
	 */
	private static final Logger logger = Logger
			.getLogger(MultipleTabValidator.class);
	
	@Override
	public ValidationMessage[] validate(TagData data) {		
		
		Object effect = data.getAttribute(EffectsConstants.EFFECT);
		Object duration = data.getAttribute(EffectsConstants.DURATION);
		Object tabsIds = data.getAttribute(EffectsConstants.TABS_IDS);
		Object tabsContentIds = data.getAttribute(EffectsConstants.TABS_CONTENT_IDS);
			
		Collection<ValidationMessage> messages = new ArrayList<ValidationMessage>();
		
		
		// Check that the effect value is included in the valid ones
		if (TagsUtils.isValueAvailableAtTranslationTime(effect)
			&& (!ArrayUtils.contains(EffectsConstants.MULTIPLE_TAB_EFFECT_VALID_TYPES, (String)effect))){
			logger.error("Param 'effect: " + (String)effect + "' is not in the valid values " 
					+ ArrayUtils.toString(EffectsConstants.MULTIPLE_TAB_EFFECT_VALID_TYPES));
			messages.add(new ValidationMessage(data.getId(), 
					"Param 'effect: " + (String)effect + "' is not in the valid values " 
					+ ArrayUtils.toString(EffectsConstants.MULTIPLE_TAB_EFFECT_VALID_TYPES)));
		}
		
		// Duration must be a float
		if (TagsUtils.isValueAvailableAtTranslationTime(duration)) {
			if (!NumberUtils.isFloat((String)duration)) {				
				logger.error("Param 'duration: " + (String)duration + "' must be a float");
				messages.add(new ValidationMessage(data.getId(), 
						"Param 'duration: " + (String)duration + "' must be a float"));
			}	
		}
				
		// tabsIds must be a JavaScript array 
		if (TagsUtils.isValueAvailableAtTranslationTime(tabsIds)) {
			if ((!JSONUtils.mayBeJSON((String)tabsIds))
					|| (JSONUtils.mayBeJSON((String)tabsIds) && !((String)tabsIds).startsWith("["))){
				logger.error("Param 'tabsIds: " + (String)tabsIds + "' must be a String representing a valid JSON Array");
				messages.add(new ValidationMessage(data.getId(), 
						"Param 'tabsIds: " + (String)tabsIds + "' must be a String representing a valid JSON Array"));
			}
		}
		
		// tabsIds must be a JavaScript array 
		if (TagsUtils.isValueAvailableAtTranslationTime(tabsContentIds)) {
			if ((!JSONUtils.mayBeJSON((String)tabsContentIds))
					|| (JSONUtils.mayBeJSON((String)tabsContentIds) && !((String)tabsContentIds).startsWith("["))){
				logger.error("Param 'tabsContentIds: " + (String)tabsContentIds + "' must be a String representing a valid JSON Array");
				messages.add(new ValidationMessage(data.getId(), 
						"Param 'tabsContentIds: " + (String)tabsContentIds + "' must be a String representing a valid JSON Array"));
			}
		}
		
		return (ValidationMessage[])messages.toArray(new ValidationMessage[messages.size()]);		
	}

}
