/**
 * PulsateValidator.java $Revision: 206 $ $Date: 2007-10-12 15:04:38 +0200 (Fri, 12 Oct 2007) $
 *
 * Copyright 2007 jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.effects;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;

import javax.servlet.jsp.tagext.TagData;
import javax.servlet.jsp.tagext.ValidationMessage;

import net.sourceforge.jstags.naming.EffectsConstants;
import net.sourceforge.jstags.utils.validation.NumberUtils;
import net.sourceforge.jstags.utils.validation.TagsUtils;

import org.apache.log4j.Logger;

/**
 * It performs the validation of the {@link Pulsate} effect parameters
 * 
 * @author sschz@users.sourceforge.net
 * @since 1.0
 * 
 */
public class PulsateValidator extends EffectValidator {
	
	/**
	 * Logger for this class
	 */
	private static final Logger logger = Logger
			.getLogger(PulsateValidator.class);


	/* (non-Javadoc)
	 * @see org.jstags.tags.effects.EffectValidator#validate(javax.servlet.jsp.tagext.TagData)
	 */
	public ValidationMessage[] validate(TagData data) {
		
		Collection<ValidationMessage> messages = new ArrayList<ValidationMessage>();
		messages.addAll(Arrays.asList(super.validate(data)));
		
		Object pulses = data.getAttribute(EffectsConstants.PULSES);
		
		// Check that the pulses value is an integer 
		if (TagsUtils.isValueAvailableAtTranslationTime(pulses)) {
			if (!NumberUtils.isInteger((String)pulses)) {				
				logger.error("Param 'pulses: " + (String)pulses + "' is not an integer");
				messages.add(new ValidationMessage(data.getId(), 
						"Param 'pulses: " + (String)pulses + "' is not an integer"));
			}				
		}
		
		return (ValidationMessage[])messages.toArray(new ValidationMessage[messages.size()]);
		
	}
	
}
