/**
 * RoundValidator.java $Revision: 206 $ $Date: 2007-10-12 15:04:38 +0200 (Fri, 12 Oct 2007) $
 *
 * Copyright 2007 jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.effects;


import java.util.ArrayList;
import java.util.Collection;

import javax.servlet.jsp.tagext.TagData;
import javax.servlet.jsp.tagext.TagExtraInfo;
import javax.servlet.jsp.tagext.ValidationMessage;

import net.sourceforge.jstags.naming.EffectsConstants;
import net.sourceforge.jstags.utils.validation.TagsUtils;

import org.apache.commons.lang.ArrayUtils;
import org.apache.log4j.Logger;

/**
 * It performs the validation of the round effect parameters
 * 
 * @author sschz@users.sourceforge.net
 * @since 1.0
 * 
 */
public class RoundValidator extends TagExtraInfo {
	/**
	 * Logger for this class
	 */
	private static final Logger logger = Logger
			.getLogger(RoundValidator.class);


	/* (non-Javadoc)
	 * @see javax.servlet.jsp.tagext.TagExtraInfo#validate(javax.servlet.jsp.tagext.TagData)
	 */
	public ValidationMessage[] validate(TagData data) {
		
		Collection<ValidationMessage> messages = new ArrayList<ValidationMessage>();
		
		Object corners = data.getAttribute(EffectsConstants.CORNERS);
		Object color = data.getAttribute(EffectsConstants.COLOR);
		Object bgColor = data.getAttribute(EffectsConstants.BG_COLOR);
		Object borderColor = data.getAttribute(EffectsConstants.BORDER_COLOR);
		
		// Check that the color is valid
		if (TagsUtils.isValueAvailableAtTranslationTime(color)) {
			if ((!EffectsConstants.COLOR_FROM_ELEMENT.equals((String)color)
					&& (!EffectsConstants.colorRegExp.matches((String)color)))) {
				logger.error("Param 'color: " + (String)color 
						+ "' must match regular expression " + EffectsConstants.colorRegExp.getPattern());
				messages.add(new ValidationMessage(data.getId(), 
						"Param 'color: " + (String)color 
						+ "' must match regular expression " + EffectsConstants.colorRegExp.getPattern()));
			}
		}

		// Check that the bgColor is valid
		if (TagsUtils.isValueAvailableAtTranslationTime(bgColor)) {
			if ((!EffectsConstants.BG_COLOR_FROM_PARENT.equals((String)bgColor))
					&& (!EffectsConstants.colorRegExp.matches((String)bgColor))) {
				logger.error("Param 'bgColor: " + (String)bgColor 
						+ "' must match regular expression " + EffectsConstants.colorRegExp.getPattern());
				messages.add(new ValidationMessage(data.getId(), 
						"Param 'bgColor: " + (String)bgColor 
						+ "' must match regular expression " + EffectsConstants.colorRegExp.getPattern()));
			}
		}

		// Check that the border is valid
		if (TagsUtils.isValueAvailableAtTranslationTime(borderColor)) {
			if (!EffectsConstants.colorRegExp.matches((String)borderColor)) {
				logger.error("Param 'border: " + (String)borderColor 
						+ "' must match regular expression " + EffectsConstants.colorRegExp.getPattern());
				messages.add(new ValidationMessage(data.getId(), 
						"Param 'border: " + (String)borderColor 
						+ "' must match regular expression " + EffectsConstants.colorRegExp.getPattern()));
			}
		}

		// Check that corners is valid
		if (TagsUtils.isValueAvailableAtTranslationTime(borderColor)) {
			String[] borders = ((String)corners).split(" ");
			for (int i = 0; i < borders.length; i++) {
				if (!ArrayUtils.contains(EffectsConstants.CORNERS_VALID_DIRECTIONS, borders[i].trim())) {
					logger.error("Param 'corners: " + (String)corners
							+ "' can't contain the value " + borders[i].trim()
							+ ". It is not included in " + ArrayUtils.toString(EffectsConstants.CORNERS_VALID_DIRECTIONS));
					messages.add(new ValidationMessage(data.getId(), 
							"Param 'corners: " + (String)corners
							+ "' can't contain the value " + borders[i].trim()
							+ ". It is not included in " + ArrayUtils.toString(EffectsConstants.CORNERS_VALID_DIRECTIONS)));
				}
			}
		}

		return (ValidationMessage[])messages.toArray(new ValidationMessage[messages.size()]);
		
	}	

}

