/**
 * SimpleEffect.java $Revision: 417 $ $Date: 2007-10-31 00:50:11 +0100 (Wed, 31 Oct 2007) $
 *
 * Copyright 2007 jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.effects;

import java.util.Map;

import javax.servlet.jsp.JspException;

import net.sf.json.JSONObject;
import net.sourceforge.jstags.naming.TemplateConstants;

/**
 * This class contains the implementation of the tag simple-effect which may perform 
 * one of several effects on an element. The effects it supports are:
 * <ul>
 * <li>appear</li>
 * <li>fade</li>
 * <li>puff</li>
 * <li>dropOut</li>
 * <li>shake</li>
 * <li>switchOff</li>
 * <li>squish</li>
 * <li>fold</li>
 * <li>shrink</li>
 * <li>opacity</li>
 * </ul>
 * 
 * This effects depend on the javascript library 
 * <a href="http://mochikit.com/">Mochikit</a> 
 *
 * @author sschz@users.sourceforge.net
 * @since 1.0
 */
public class SimpleEffect extends Effect {
	
	private static final long serialVersionUID = -3157533973467158849L;

	private String type;
	
	/**
	 * @return the type of effect to be performed
	 */
	public String getType() {
		return type;
	}

	/**
	 * @param type the type of effect to be performed
	 */
	public void setType(String type) {
		this.type = type;
	}

	/* (non-Javadoc)
	 * @see org.jstags.utils.tags.JSTagsTagSupport#getTemplateName()
	 */
	protected String getTemplateName() throws JspException {		
		return TemplateConstants.SIMPLE_EFFECT_TEMPLATE_NAME;
	}
		
	/* (non-Javadoc)
	 * @see net.sourceforge.jstags.tags.effects.Effect#getTemplateNameValuePairs()
	 */
	@Override
	protected Map<String, String> getTemplateNameValuePairs() {
		Map<String, String> map = super.getTemplateNameValuePairs();
		
		JSONObject jsObject = JSONObject.fromString(map.get(TemplateConstants.PARAMETERS_VAR_NAME));		
		jsObject.put(TemplateConstants.EFFECT_PARAM_NAME, getType());
		
		map.put(TemplateConstants.PARAMETERS_VAR_NAME, jsObject.toString(TemplateConstants.INDENT_FACTOR));
		return map;
	}		
}
