/**
 * SlideValidator.java $Revision: 206 $ $Date: 2007-10-12 15:04:38 +0200 (Fri, 12 Oct 2007) $
 *
 * Copyright 2007 jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.effects;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;

import javax.servlet.jsp.tagext.TagData;
import javax.servlet.jsp.tagext.ValidationMessage;

import net.sourceforge.jstags.naming.EffectsConstants;
import net.sourceforge.jstags.utils.validation.NumberUtils;
import net.sourceforge.jstags.utils.validation.TagsUtils;

import org.apache.commons.lang.ArrayUtils;
import org.apache.log4j.Logger;

/**
 * Performs the validation of the {@link Slide} effect parameters
 *
 * @author sschz@users.sourceforge.net
 * @since 1.0
 * 
 */
public class SlideValidator extends EffectValidator {
	/**
	 * Logger for this class
	 */
	private static final Logger logger = Logger.getLogger(SlideValidator.class);
	
	@Override
	public ValidationMessage[] validate(TagData data) {
		
		Collection<ValidationMessage> messages = new ArrayList<ValidationMessage>();
		messages.addAll(Arrays.asList(super.validate(data)));
		
		Object direction = data.getAttribute(EffectsConstants.DIRECTION);
		Object scaleMode = data.getAttribute(EffectsConstants.SCALE_MODE);
		Object scaleFrom = data.getAttribute(EffectsConstants.SCALE_FROM);
		Object scaleTo = data.getAttribute(EffectsConstants.SCALE_TO);
		
		// Check that the direction value is included in the valid ones
		if ((TagsUtils.isValueAvailableAtTranslationTime(direction))
			&& (!ArrayUtils.contains(EffectsConstants.SLIDE_VALID_DIRECTIONS, (String)direction))){
			logger.error("Param 'direction: " + (String)direction + "' is not in the valid values " 
					+ ArrayUtils.toString(EffectsConstants.SLIDE_VALID_DIRECTIONS));			
			messages.add(new ValidationMessage(data.getId(), 
					"Param 'direction: " + (String)direction + "' is not in the valid values " 
					+ ArrayUtils.toString(EffectsConstants.SLIDE_VALID_DIRECTIONS)));
		}
		
		// Check that the scaleMode value is included in the valid ones
		if (TagsUtils.isValueAvailableAtTranslationTime(scaleMode)
			&& (!ArrayUtils.contains(EffectsConstants.SLIDE_VALID_SCALE_MODES, (String)scaleMode))){
			logger.error("Param 'scaleMode: " + (String)scaleMode + "' is not in the valid values " 
					+ ArrayUtils.toString(EffectsConstants.SLIDE_VALID_SCALE_MODES));
			messages.add(new ValidationMessage(data.getId(), 
					"Param 'scaleMode: " + (String)scaleMode + "' is not in the valid values " 
					+ ArrayUtils.toString(EffectsConstants.SLIDE_VALID_SCALE_MODES)));
		}
		
		// Check that the scaleFrom value is a float 
		if (TagsUtils.isValueAvailableAtTranslationTime(scaleFrom)) {							 
			if (!NumberUtils.isFloat((String)scaleFrom)) {
				logger.error("Param 'scaleFrom: " + (String)scaleFrom + "' is not a float");
				messages.add(new ValidationMessage(data.getId(), 
						"Param 'scaleFrom: " + (String)scaleFrom + "' is not a float"));
			}				
		}
		
		// Check that the scaleTo value is a float 
		if (TagsUtils.isValueAvailableAtTranslationTime(scaleTo)) {
			if (!NumberUtils.isFloat((String)scaleTo)) {
				logger.error("Param 'scaleTo: " + (String)scaleTo + "' is not in not a float");
				messages.add(new ValidationMessage(data.getId(), 
						"Param 'scaleTo: " + (String)scaleTo + "' is not in not a float"));
			}		
			
		}
		
		return (ValidationMessage[])messages.toArray(new ValidationMessage[messages.size()]);	
	}	
}
