/**
 * ToggleValidator.java $Revision: 207 $ $Date: 2007-10-12 15:08:01 +0200 (Fri, 12 Oct 2007) $
 *
 * Copyright 2007 jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.effects;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;

import javax.servlet.jsp.tagext.TagData;
import javax.servlet.jsp.tagext.ValidationMessage;

import net.sourceforge.jstags.naming.EffectsConstants;
import net.sourceforge.jstags.utils.validation.TagsUtils;

import org.apache.commons.lang.ArrayUtils;
import org.apache.log4j.Logger;

/**
 * Performs the validation of the {@link Toggle} effect parameters
 *
 * @author sschz@users.sourceforge.net
 * @since 1.0
 * 
 */
public class ToggleValidator extends EffectValidator {
	/**
	 * Logger for this class
	 */
	private static final Logger logger = Logger.getLogger(SlideValidator.class);

	
	@Override
	public ValidationMessage[] validate(TagData data) {
		
		Collection<ValidationMessage> messages = new ArrayList<ValidationMessage>();
		messages.addAll(Arrays.asList(super.validate(data)));
		
		Object effect = data.getAttribute(EffectsConstants.EFFECT);
		
		// Check that the effect value is included in the valid ones
		if (TagsUtils.isValueAvailableAtTranslationTime(effect)
			&& (!ArrayUtils.contains(EffectsConstants.TOGGLE_VALID_EFFECTS, (String)effect))){
			logger.error("Param 'effect: " + (String)effect + "' is not in the valid values " 
					+ ArrayUtils.toString(EffectsConstants.TOGGLE_VALID_EFFECTS));
			messages.add(new ValidationMessage(data.getId(), "Param 'effect: " + (String)effect + "' is not in the valid values " 
					+ ArrayUtils.toString(EffectsConstants.TOGGLE_VALID_EFFECTS)));
		}
		
		return (ValidationMessage[])messages.toArray(new ValidationMessage[messages.size()]);		
		
	}	
}
