/**
 * DualCombo.java $Revision: 417 $ $Date: 2007-10-31 00:50:11 +0100 (Wed, 31 Oct 2007) $
 *
 * Copyright 2007 jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.forms;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.jsp.JspException;

import net.sourceforge.jstags.naming.TemplateConstants;
import net.sourceforge.jstags.tags.JSTagsTagSupport;

import org.apache.commons.lang.StringUtils;

/**
 * It allows a combo being filled with data fetched asynchronously (ajax) from
 * a given url based on the value of another combo box.  
 * 
 * This tag depends on the JavaScript library 
 * <a href="http://mochikit.com">Mochikit</a> together with
 * <a href="http://jstags.sourceforge.net/">JSTags</a> 
 * JavaScript libraries
 * 
 * @author sschz@users.sourceforge.net
 * @since 1.1
 */
public class DualCombo extends JSTagsTagSupport {

	private static final long serialVersionUID = 3868437918854731032L;

//	private static final Logger logger = Logger.getLogger(DualCombo.class);

	private String url;
	
	private String sourceFormName;
	
	private String sourceFieldName;
	
	private String targetFormName;
	
	private String targetFieldName;
	
	private String nameValuePairs;
		
	/* (non-Javadoc)
	 * @see net.sourceforge.jstags.tags.JSTagsBodyTagSupport#getTemplateName()
	 */
	@Override
	protected String getTemplateName() throws JspException {
		return TemplateConstants.DUAL_COMBO_TEMPLATE_NAME;
	}

	/* (non-Javadoc)
	 * @see net.sourceforge.jstags.tags.JSTagsBodyTagSupport#getTemplateNameValuePairs()
	 */
	@Override
	protected Map<String, String> getTemplateNameValuePairs() {
		
		Map<String, String> map = new HashMap<String, String>();
		
		map.put(TemplateConstants.URL_VAR_NAME, getUrl());
		map.put(TemplateConstants.SOURCE_FORM_NAME_VAR_NAME, getSourceFormName());
		map.put(TemplateConstants.SOURCE_FIELD_NAME_VAR_NAME, getSourceFieldName());
		map.put(TemplateConstants.TARGET_FORM_NAME_VAR_NAME, getTargetFormName());
		map.put(TemplateConstants.TARGET_FIELD_NAME_VAR_NAME, getTargetFieldName());
		map.put(TemplateConstants.NAME_VALUE_PAIRS_VAR_NAME, 
				(StringUtils.isEmpty(getNameValuePairs()) ? "{}" : getNameValuePairs()));
				
		return map;
	}

	/**
	 * @return URL the data to fill the second combo will be retrieved from.
	 */
	public String getUrl() {
		return url;
	}

	public void setUrl(String url) {
		this.url = url;
	}

	/**
	 * @return Name of the form the first combo belongs to.
	 */
	public String getSourceFormName() {
		return sourceFormName;
	}

	public void setSourceFormName(String sourceFormName) {
		this.sourceFormName = sourceFormName;
	}

	/**
	 * @return Name of the field in the first combo that will be used to fetched data from
          the given URL based on its value.
	 */
	public String getSourceFieldName() {
		return sourceFieldName;
	}

	public void setSourceFieldName(String sourceFieldName) {
		this.sourceFieldName = sourceFieldName;
	}

	/**
	 * @return Name of the form the second combo belongs to.
	 */
	public String getTargetFormName() {
		return targetFormName;
	}

	public void setTargetFormName(String targetFormName) {
		this.targetFormName = targetFormName;
	}

	/**
	 * @return Name of the field in the second combo, the one that will be filled with the 
          data fetched from the given URL.
	 */
	public String getTargetFieldName() {
		return targetFieldName;
	}

	public void setTargetFieldName(String targetFieldName) {
		this.targetFieldName = targetFieldName;
	}

	/**
	 * @return a ',' separated object of pairs name:value. i.e. {name1:'value1',name2:56}
            These parameters will be added, with the value given here, to the request.
	 */
	public String getNameValuePairs() {
		return nameValuePairs;
	}

	public void setNameValuePairs(String nameValuePairs) {
		this.nameValuePairs = nameValuePairs;
	}
}
