/**
 * FormRule.java $Revision: 344 $ $Date: 2007-10-21 03:47:55 +0200 (Sun, 21 Oct 2007) $
 *
 * Copyright 2007 jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.forms;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.TagSupport;

import net.sf.json.JSONObject;

/**
 * It represents a rule used to configure a form. It is linked to a form field and contains the information on 
 * what form fields will be displayed for any value of that field
 * 
 * @author sschz@users.sourceforge.net
 * @since 1.0
 * 
 */
public class FormRule extends TagSupport {
	
	private static final long serialVersionUID = -741600610090540513L;
	
	private String fieldName;
	private String pairs;
	
	/**
	 * @return fieldName name of the form field that is being configured 
	 */
	public String getFieldName() {
		return fieldName;
	}
	
	/**
	 * @param fieldName name of the form field that is being configured 
	 */
	public void setFieldName(String fieldName) {
		this.fieldName = fieldName;
	}
	
	/**
	 * @return a {@link String} in the form 
	 * {"fieldValue1" : ["fieldId1", "fieldId2"], "fieldValue2": ["fieldId1", "fieldId3"]} where:
	 * <ul>
	 * <li>fieldValueX: represents a possible value of the fieldId. It can be also between ' or without quotes</li>
	 * <li>fieldIdX: represents the id of a field to be displayed when fieldId is fieldValueX. It can be
	 * between ' or without quotes if it is a number</li>
	 * </ul>
	 * You can't mix " and '
	 * If a fieldIdX is '*', then all the fields will be displayed
	 */
	public String getPairs() {
		return pairs;
	}
	
	/**
	 * @param pairs {@link String} in the form 
	 * {"fieldValue1" : ["fieldId1", "fieldId2"], "fieldValue2": ["fieldId1", "fieldId3"]}
	 * representing what fields to be displayed for every value of the current field (the one identified by fieldId)
	 */
	public void setPairs(String pairs) {
		this.pairs = pairs;
	}
	
	/* (non-Javadoc)
	 * @see javax.servlet.jsp.tagext.TagSupport#doStartTag()
	 */
	public int doStartTag() throws JspException {
		
		FormRules formRules = (FormRules) getParent();
		
		formRules.addRule(getFieldName(), JSONObject.fromString(getPairs()));
		 
		return SKIP_BODY;
	}
		
}
