/**
 * FormRules.java $Revision: 344 $ $Date: 2007-10-21 03:47:55 +0200 (Sun, 21 Oct 2007) $
 *
 * Copyright 2007 jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.forms;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.jsp.JspException;

import net.sf.json.JSONArray;
import net.sf.json.JSONObject;
import net.sourceforge.jstags.naming.TemplateConstants;
import net.sourceforge.jstags.tags.JSTagsBodyTagSupport;

import org.apache.log4j.Logger;


/**
 * It allows the configuration of a form(HTML form) so that, the input fields can 
 * be shown and hidden depending on the values of other fields in the form 
 * 
 * This effect depends on the javascript library 
 * <a href="http://mochikit.com">Mochikit</a>
 * 
 * @author sschz@users.sourceforge.net
 * @since 1.0
 * 
 */
public class FormRules extends JSTagsBodyTagSupport {
	/**
	 * Logger for this class
	 */
	private static final Logger logger = Logger.getLogger(FormRules.class);

	private static final long serialVersionUID = 3214567323271519686L;

	private String formName;
	private String displayAlways;
	
	private JSONArray rules;
	

	/* (non-Javadoc)
	 * @see javax.servlet.jsp.tagext.BodyTagSupport#doStartTag()
	 */
	public int doStartTag() throws JspException {
		
		rules = new JSONArray();
		
		return EVAL_BODY_BUFFERED;
	}
	

	/* (non-Javadoc)
	 * @see org.jstags.utils.tags.JSTagsBodyTagSupport#getTemplateName()
	 */
	protected String getTemplateName() throws JspException {
		return TemplateConstants.FORM_RULES_TEMPLATE_NAME;
	}

	/* (non-Javadoc)
	 * @see org.jstags.utils.tags.JSTagsBodyTagSupport#getTemplateNameValuePairs()
	 */
	protected Map<String, String> getTemplateNameValuePairs() {
	
		Map<String, String> map = new HashMap<String, String>();
		
		map.put(TemplateConstants.FORM_NAME_VAR_NAME, getFormName());
		map.put(TemplateConstants.DISPLAY_ALWAYS_VAR_NAME, getDisplayAlways());
		
		logger.debug("All rules: " + rules.toString(TemplateConstants.INDENT_FACTOR));
		
		map.put(TemplateConstants.FORM_RULES_VAR_NAME, getRules().toString());
		
		return map;
		
	}
	
	/**
	 * @return the fields to be displayed when the page is loaded and at any other time. It is 
	 * a {@link String} in the form ['fieldId1', 'fieldId2', ...] where fieldIdX represents 
	 * the id of a form field to be displayed
	 */
	public String getDisplayAlways() {
		return displayAlways;
	}

	public void setDisplayAlways(String displayAlways) {
		this.displayAlways = displayAlways;
	}
	
	/**
	 * @param field id of the form field 
	 * @param pairs {@link JSONObject} with the information on what fields are to be displayed
	 * when field has a certain value. This object, has the form {"fieldValue1": "[fieldToShow1, 
	 * fieldToShow2]", "fieldValue2": "[fieldToShow3, fieldToShow4]"} where: 
	 * <ul>
	 * <li>
	 * fieldValueX: represents a possible value of the field that, when set, will
	 * make other form fields to be shown or hidden(the ones in []). 
	 * </li>
	 * <li>
	 * fieldToShowX: represents a field that will be shown when the field value is
	 * equals to fieldValueY. If fieldToShowX is '*', all the fields in the form
	 * will be displayed when that rule is applied. 
	 * </li> 
	 * </ul>
	 */
	public void addRule(String field, JSONObject pairs){
		
		rules.put(new JSONObject().put(field, pairs));
	}

	/**
	 * @return the name of the form that is being configured
	 */
	public String getFormName() {
		return formName;
	}

	/**
	 * @param formName the name of the form that is being configured
	 */
	public void setFormName(String formName) {
		this.formName = formName;
	}

	/**
	 * @return all the rules used to configure the form. Every rule is set by means of a {@link FormRule} tag
	 */
	public JSONArray getRules() {
		return rules;
	}	
}
