/**
 * Link.java $Revision: 252 $ $Date: 2007-10-13 15:33:12 +0200 (Sat, 13 Oct 2007) $
 *
 * Copyright ${year} jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.table;

import org.apache.log4j.Logger;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.TagSupport;


import net.sf.json.JSONObject;
import net.sourceforge.jstags.naming.TemplateConstants;

/**
 * It allows the configuration of an asynchronous table so that it can
 * contain links to the next and previous pages when results are paginated.
 * It is a child of {@link Table} tag
 * 
 * @author sschz@users.sourceforge.net
 * @since 1.0
 *  
 */
public class Link extends TagSupport {
	/**
	 * Logger for this class
	 */
	private static final Logger logger = Logger.getLogger(Link.class);
	
	private static final long serialVersionUID = -6034725293800828833L;
	
	private String type;
	private String containerId;
	private String src;
	private String title;
	private String alt;
	
	
	/**
	 * @return url of the image used to represent the link
	 */
	public String getSrc() {
		return src;
	}
	/**
	 * @param src url of the image used to represent the link
	 */
	public void setSrc(String src) {
		this.src = src;
	}
	/**
	 * @return title of the link. To be used as title attribute of the
	 * img tag that will be created to represent the link
	 */
	public String getTitle() {
		return title;
	}
	/**
	 * @param title title of the link. To be used as title attribute of the
	 * img tag that will be created to represent the link
	 */
	public void setTitle(String title) {
		this.title = title;
	}
	/**
	 * @return identifier of the html element that will contain the link
	 */
	public String getContainerId() {
		return containerId;
	}
	/**
	 * @param containerId identifier of the element whose child will
	 * be this link
	 */
	public void setContainerId(String containerId) {
		this.containerId = containerId;
	}
	/**
	 * @return the text used to represent the link when there is
	 * no image
	 */
	public String getAlt() {
		return alt;
	}
	/**
	 * @param alt text to be used in the link when there is no image
	 */
	public void setAlt(String alt) {
		this.alt = alt;
	}
	
	/**
	 * @return the type of the link, that is, whether it is a 
	 * next or previous link
	 */
	public String getType() {
		return type;
	}
	/**
	 * @param type type of link. Valid values are:
	 * <ul>
	 * <li>previous</li>
	 * <li>next</li>
	 * </ul>
	 */
	public void setType(String type) {
		this.type = type;
	}
	
	/* (non-Javadoc)
	 * @see javax.servlet.jsp.tagext.TagSupport#doStartTag()
	 */
	public int doStartTag() throws JspException {
				
		JSONObject link = new JSONObject();
		link.put(TemplateConstants.CONTAINER_ID_PARAM_NAME, getContainerId());
		link.put(TemplateConstants.SRC_PARAM_NAME, getSrc());
		link.put(TemplateConstants.ALT_PARAM_NAME, getAlt());
		link.put(TemplateConstants.TITLE_PARAM_NAME, getTitle());
		
		Table parent = (Table)getParent();
		
		logger.debug("Going to add link " + link.toString(TemplateConstants.INDENT_FACTOR) 
				+ " to: " + parent.getLinks()
				+ " with type " + getType());
		
		parent.getLinks().set(getType(), link);
		
		logger.debug("Link has been added. New value is: " 
				+ parent.getLinks().toString());
		
		
		return SKIP_BODY;
	}	
}
