/**
 * LinkValidator.java $Revision: 252 $ $Date: 2007-10-13 15:33:12 +0200 (Sat, 13 Oct 2007) $
 *
 * Copyright ${year} jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.table;

import java.util.ArrayList;
import java.util.Collection;

import javax.servlet.jsp.tagext.TagData;
import javax.servlet.jsp.tagext.TagExtraInfo;
import javax.servlet.jsp.tagext.ValidationMessage;

import net.sourceforge.jstags.naming.TableConstants;

import org.apache.commons.lang.ArrayUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;

/**
 * It performs the validation of every link tag. Such links should be of 
 * one of the valid types:
 * <ul>
 * <li>previous</li>
 * <li>next</li>
 * </ul>
 * 
 * @author sschz@users.sourceforge.net
 * @since 1.0
 *  
 */
public class LinkValidator extends TagExtraInfo {
	/**
	 * Logger for this class
	 */
	private static final Logger logger = Logger.getLogger(LinkValidator.class);
		
	/* (non-Javadoc)
	 * @see javax.servlet.jsp.tagext.TagExtraInfo#validate(javax.servlet.jsp.tagext.TagData)
	 */
	public ValidationMessage[] validate(TagData data) {

		Collection<ValidationMessage> messages = new ArrayList<ValidationMessage>();

		String type = (String)data.getAttribute(TableConstants.LINK_TYPE_PARAM_NAME);
		
		// Check that the transition value is included in the valid transitions
		if ((!StringUtils.isEmpty(type))
			&& (!data.getAttribute(TableConstants.LINK_TYPE_PARAM_NAME).equals(TagData.REQUEST_TIME_VALUE))
			&& (!ArrayUtils.contains(TableConstants.VALID_LINK_TYPES, type))){
			logger.error("Param 'type: " + type + "' is not in the valid values");
			messages.add(new ValidationMessage(data.getId(), 
					"Param 'type: " + type + "' is not in the valid values"));
		}
				
		return (ValidationMessage[])messages.toArray(new ValidationMessage[messages.size()]);
	}
	
}

