/**
 * Table.java $Revision: 417 $ $Date: 2007-10-31 00:50:11 +0100 (Wed, 31 Oct 2007) $
 *
 * Copyright ${year} jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.table;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.jsp.JspException;

import net.sf.json.JSONArray;
import net.sf.json.JSONObject;
import net.sourceforge.jstags.naming.TableConstants;
import net.sourceforge.jstags.naming.TemplateConstants;
import net.sourceforge.jstags.tags.JSTagsBodyTagSupport;

import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;

 
/**
 * It allows the creation of a table whose contents will be retrieved
 * by means of an asynchronous call to the server.  
 * 
 * This tag depends on the JavaScript library 
 * <a href="http://mochikit.com">Mochikit</a> together with
 * <a href="http://jstags.sourceforge.net/">JSTags</a> 
 * JavaScript libraries
 * 
 * @author sschz@users.sourceforge.net
 * @since 1.0
 * 
 */
public class Table extends JSTagsBodyTagSupport {
	/**
	 * Logger for this class
	 */
	private static final Logger logger = Logger.getLogger(Table.class);
		
	private static final long serialVersionUID = -5378487997149017005L;
	
	private String targetId;
	private String tableClass;
	private String oddRowClass;
	
	private String url;           
	private String frequency;
	private String decay;
		
	private String shooterId;
	private String event;
	
	private String formNames;
	private String params;
	private String nameValuePairs;
	
	private String startIndex;
	private String count;
	private JSONObject links;	
	
	private String function;
		
	
	/* (non-Javadoc)
	 * @see org.jstags.utils.tags.JSTagsBodyTagSupport#getTemplateName()
	 */
	protected String getTemplateName() throws JspException {
		return TemplateConstants.TABLE_TEMPLATE_NAME;
	}
	
	/**
	 * @return {@link JSONObject} with information on the links used
	 * to allow pagination, that is, previous and next links. 
	 */
	public JSONObject getLinks() {
		return links;
	}

	/**
	 * @param links {@link JSONObject} with information on the links used
	 * to allow pagination, that is, previous and next links. 
	 */
	public void setLinks(JSONObject links) {
		this.links = links;
	}

	/**
	 * @return number of items to be retrieved from the server on every
	 * request
	 */
	public String getCount() {
		return count;
	}

	/**
	 * @param count number of items to be retrieved from the server
	 * on every request
	 */
	public void setCount(String count) {
		this.count = count;
	}

	/**
	 * @return css class to be used for every odd row
	 */
	public String getOddRowClass() {
		return oddRowClass;
	}

	/**
	 * @param oddRowClass css class to be used with every odd row
	 */
	public void setOddRowClass(String oddRowClass) {
		this.oddRowClass = oddRowClass;
	}

	/**
	 * @return index of the first item to be retrieved from the server
	 */
	public String getStartIndex() {
		return startIndex;
	}

	/**
	 * @param startIndex index of the first item to be retrieved from
	 * the server
	 */
	public void setStartIndex(String startIndex) {
		this.startIndex = startIndex;
	}
	
	/* (non-Javadoc)
	 * @see org.jstags.utils.tags.JSTagsBodyTagSupport#getTemplateNameValuePairs()
	 */
	protected Map<String, String> getTemplateNameValuePairs() {
		
		Map<String, String> map = new HashMap<String, String>();
		
		JSONObject jsObject = new JSONObject();
		
		JSONObject tableRequestParamsJsonObject = new JSONObject();
				
		tableRequestParamsJsonObject.put(TemplateConstants.URL_PARAM_NAME, getUrl());
		
		if (!StringUtils.isEmpty(getNameValuePairs())) {
			tableRequestParamsJsonObject.put(TemplateConstants.NAME_VALUE_PAIRS_PARAM_NAME, JSONObject.fromString(getNameValuePairs()));
		}
		if (!StringUtils.isEmpty(getParams())) {
			tableRequestParamsJsonObject.put(TemplateConstants.PARAMS_PARAM_NAME, JSONArray.fromString(getParams()));
		} 
		if (!StringUtils.isEmpty(getFormNames())) {
			tableRequestParamsJsonObject.put(TemplateConstants.FORM_NAMES_PARAM_NAME, JSONArray.fromString(getFormNames()));
		}
		
		tableRequestParamsJsonObject.put(TemplateConstants.REQUEST_METHOD_PARAM_NAME, "post");
		tableRequestParamsJsonObject.put(TemplateConstants.TARGET_ID_PARAM_NAME, getTargetId());
		
		if (!StringUtils.isEmpty(getTableClass())) {
			tableRequestParamsJsonObject.put(TemplateConstants.TABLE_CSS_CLASS_PARAM_NAME, getTableClass());
		}
		if (!StringUtils.isEmpty(getOddRowClass())) {
			tableRequestParamsJsonObject.put(TemplateConstants.ODD_ROW_CSS_CLASS_PARAM_NAME, getOddRowClass());
		}		
		
		if (!StringUtils.isEmpty(getFrequency())) {
			tableRequestParamsJsonObject.put(TemplateConstants.FREQUENCY_PARAM_NAME, getFrequency());
		}
		
		if (!StringUtils.isEmpty(getDecay())) {
			tableRequestParamsJsonObject.put(TemplateConstants.DECAY_PARAM_NAME, getDecay());
		}
		
		if (!StringUtils.isEmpty(getStartIndex())) {
			tableRequestParamsJsonObject.put(TemplateConstants.START_INDEX_PARAM_NAME, getStartIndex());
		}
		if (!StringUtils.isEmpty(getCount())) {
			tableRequestParamsJsonObject.put(TemplateConstants.COUNT_PARAM_NAME, getCount());
		}
		
		if (!StringUtils.isEmpty(getStartIndex())) {
			tableRequestParamsJsonObject.put(TemplateConstants.LINKS_PARAM_NAME, getLinks());
			
		}
		
		if (!StringUtils.isEmpty(getShooterId())) {
			tableRequestParamsJsonObject.put(TemplateConstants.SHOOTER_ID_PARAM_NAME, getShooterId());
			tableRequestParamsJsonObject.put(TemplateConstants.EVENT_PARAM_NAME, getEvent());
			jsObject.put(TemplateConstants.SHOOTER_ID_PARAM_NAME, getShooterId());
			jsObject.put(TemplateConstants.EVENT_PARAM_NAME, getEvent());			
		} 
		
		jsObject.put(TemplateConstants.TABLE_REQUEST_PARAMETERS_PARAM_NAME, tableRequestParamsJsonObject.toString(TemplateConstants.INDENT_FACTOR));
		if (!StringUtils.isEmpty(getFunction())) {
			map.put(TemplateConstants.SUCCESS_FUNCTION_NAME_VAR_NAME, getFunction());
		} else {
			map.put(TemplateConstants.SUCCESS_FUNCTION_NAME_VAR_NAME, 
					TemplateConstants.SUCCESS_FUNCTION_VAR_VALUE);	
		}
					
		logger.debug("Json object with the options: " + tableRequestParamsJsonObject.toString());
		logger.debug("All the data: " + jsObject.toString(TemplateConstants.INDENT_FACTOR));
		
		map.put(TemplateConstants.PARAMETERS_VAR_NAME, jsObject.toString(TemplateConstants.INDENT_FACTOR));
		
		return map;
	}

	/**
	 * /**
	 * If this attribute is set, the content will be refreshed every 
	 * refresh seconds. If the content retrieved is the same as the 
	 * last time it was requested, it will be refreshed again after 
	 * refresh + delay seconds instead of refresh. The time between 
	 * every refresh will be increased in delay seconds until the
	 * content changes and it's value be reseted to refresh seconds again
	 * @return the delay to be added after a request has returned 
	 * unchanged data
	 */	 
	public String getDecay() {
		return decay;
	}

	/**
	 * If this attribute is set, the content will be refreshed every 
	 * refresh seconds. If the content retrieved is the same as the 
	 * last time it was requested, it will be refreshed again after 
	 * refresh + delay seconds instead of refresh. The time between 
	 * every refresh will be increased in delay seconds until the
	 * content changes and it's value be reseted to refresh seconds again
	 * @param delay the delay to be added after a request has returned 
	 * unchanged data
	 */
	public void setDecay(String decay) {
		this.decay = decay;
	}

	/**
	 * @return the event on which the request will be executed. Such an event is
	 * attached to the element represented by shooterId    
	 */
	public String getEvent() {
		return event;
	}

	/**
	 * @param event the event on which the request will be executed. Such an event is
	 * attached to the element represented by shooterId    
	 */
	public void setEvent(String event) {
		this.event = event;
	}

	/**
	 * @return <code>,</code> separated array of values in the form ['name1', 'name2'], 
	 * all the params of each form named in the attribute value (identified by the 
	 * name provided here) will be sent with every request  
	 */
	public String getFormNames() {
		return formNames;
	}

	/**
	 * @param forms <code>,</code> separated array of values in the form ['name1', 'name2'], 
	 * all the params of each form named in the attribute value (identified by the name provided 
	 * here) will be sent with every request  
	 */
	public void setFormNames(String formNames) {
		this.formNames = formNames;
	}

	/**
	 * If this attribute is set, the function identified by its value will
	 * be used instead of the default one provided in order to perform any 
	 * task on the response. Such a function will receive the same 
	 * parameters as the default one.
	 * @return the function name
	 */
	public String getFunction() {
		return function;
	}

	/**
	 * If this attribute is set, the function identified by its value will
	 * be used instead of the default one provided in order to perform any 
	 * task on the response. Such a function will receive the same 
	 * parameters as the default one.
	 * @param function function name
	 */
	public void setFunction(String function) {
		this.function = function;
	}

	/**
	 * These params will be added, with the value given here, to the 
	 * request
	 * @return a <code>,</code> separated object of pairs <code>name:value</code>.
	 * i.e. <code>{name1:'value1',name2:'value2'}</code>
	 */
	public String getNameValuePairs() {
		return nameValuePairs;
	}

	/**
	 * These params will be added, with the value given here, to the 
	 * request
	 * @param nameValuePairs a <code>,</code> separated object of pairs <code>name:value</code>.
	 * i.e. <code>{name1:'value1',name2:'value2'}</code>
	 */
	public void setNameValuePairs(String nameValuePairs) {
		this.nameValuePairs = nameValuePairs;
	}

	/**
	 * @return <code>,</code> separated array of values in the form ['param1', 'param2'], 
	 * the value of every param included in its value (identified by the its id provided 
	 * here) will be sent with every request.   
	 */
	public String getParams() {
		return params;
	}

	/**
	 * @param params <code>,</code> separated array of values in the form ['param1', 'param2'], 
	 * the value of every param included in its value (identified by the its id provided 
	 * here) will be sent with every request.   
	 */
	public void setParams(String params) {
		this.params = params;
	}

	/**
	 * If this attribute is set, the content will be refreshed every 
	 * refresh seconds 
	 * @return time between every data refresh
	 */
	public String getFrequency() {
		return frequency;
	}

	/**
	 * If this attribute is set, the content will be refreshed every 
	 * refresh seconds 
	 * @param frequency time between every data refresh
	 */
	public void setFrequency(String frequency) {
		this.frequency = frequency;
	}

	/**
	 * @return the identifier of the element to which the event provided by the event attribute
	 * will be attached
	 */
	public String getShooterId() {
		return shooterId;
	}

	/**
	 * @param shooterId the element to which the event provided by the event attribute
	 * will be attached
	 */
	public void setShooterId(String shooter) {
		this.shooterId = shooter;
	}

	/**
	 * @return Css class to be used for the table
	 */
	public String getTableClass() {
		return tableClass;
	}

	/**
	 * @param tableClass Css class to be used for the table
	 */
	public void setTableClass(String tableClass) {
		this.tableClass = tableClass;
	}

	/**
	 * @return The region on the page the response will be written to
	 */
	public String getTargetId() {
		return targetId;
	}

	/**
	 * @param targetId The region on the page the response will be written to
	 */
	public void setTargetId(String target) {
		this.targetId = target;
	}

	/**
	 * @return Url the data will be retrieved from
	 */
	public String getUrl() {
		return url;
	}

	/**
	 * @param url Url the data will be retrieved from
	 */
	public void setUrl(String url) {
		this.url = url;
	}

	@Override
	public int doStartTag() throws JspException {
		
		links = new JSONObject();
		
		return EVAL_BODY_BUFFERED;
	}

	@Override
	public int doAfterBody() throws JspException {
		
		// If the table is paginated, both next and previous links are required
		if (!StringUtils.isEmpty(startIndex)) {
			if (!links.has(TableConstants.NEXT_LINK_PARAM_NAME)
					|| (!links.has(TableConstants.PREVIOUS_LINK_PARAM_NAME))) {
				logger.error("Both 'next' and 'previous' links must be set." + links.toString() + " is not valid");
				throw new JspException("Both 'next' and 'previous' links must be set." + links.toString() + " is not valid");
			}
		}
		
		return EVAL_PAGE;
	}

	
	
}
