/**
 * XSLTTransformerValidator.java $Revision: 417 $ $Date: 2007-10-31 00:50:11 +0100 (Wed, 31 Oct 2007) $
 *
 * Copyright ${year} jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.tags.transform;

import java.util.ArrayList;
import java.util.Collection;

import javax.servlet.jsp.tagext.TagData;
import javax.servlet.jsp.tagext.TagExtraInfo;
import javax.servlet.jsp.tagext.ValidationMessage;

import net.sf.json.util.JSONUtils;
import net.sourceforge.jstags.naming.TransformConstants;
import net.sourceforge.jstags.utils.validation.TagsUtils;

import org.apache.log4j.Logger;

/**
 * 
 * It performs the validation of the {@link XSLTTransformer} tag attributes
 * 
 * @author sschz@users.sourceforge.net
 * @since 1.0
 *
 */
public class XSLTTransformerValidator extends TagExtraInfo {
	/**
	 * Logger for this class
	 */
	private static final Logger logger = Logger
			.getLogger(XSLTTransformerValidator.class);


	/* (non-Javadoc)
	 * @see javax.servlet.jsp.tagext.TagExtraInfo#validate(javax.servlet.jsp.tagext.TagData)
	 */
	public ValidationMessage[] validate(TagData data) {

		Collection<ValidationMessage> messages = new ArrayList<ValidationMessage>();

		Object nameValuePairs = data.getAttribute(TransformConstants.NAME_VALUE_PAIRS_TAG_ATTR_NAME);
		Object formNames = data.getAttribute(TransformConstants.FORM_NAMES_TAG_ATTR_NAME);
		Object params = data.getAttribute(TransformConstants.PARAMS_TAG_ATTR_NAME);
					
		// nameValuePairs must be a javascript object 
		if (TagsUtils.isValueAvailableAtTranslationTime(nameValuePairs)) {
			if ((!JSONUtils.mayBeJSON((String)nameValuePairs))
					|| (JSONUtils.mayBeJSON((String)nameValuePairs) && !((String)nameValuePairs).startsWith("{"))){
				logger.error("Param 'nameValuePairs: " + (String)nameValuePairs 
						+ "' must be a String representing a valid JSON Object");
				messages.add(new ValidationMessage(data.getId(), 
						"Param 'nameValuePairs: " + (String)nameValuePairs 
						+ "' must be a String representing a valid JSON Object"));
			}
		}
			
		// formNames must be a JavaScript array 
		if (TagsUtils.isValueAvailableAtTranslationTime(formNames)) {
			if ((!JSONUtils.mayBeJSON((String)formNames))
					|| (JSONUtils.mayBeJSON((String)formNames) && !((String)formNames).startsWith("["))){
				logger.error("Param 'forms: " + (String)formNames + "' must be a String representing a valid JSON Array");
				messages.add(new ValidationMessage(data.getId(), 
						"Param 'forms: " + (String)formNames + "' must be a String representing a valid JSON Array"));
			}
		}
		
		// params must be a JavaScript array
		if (TagsUtils.isValueAvailableAtTranslationTime(params)) {
			if ((!JSONUtils.mayBeJSON((String)params))
					|| (JSONUtils.mayBeJSON((String)params) && !((String)params).startsWith("{"))){
				logger.error("Param 'params: " + (String)params + "' must be a String representing a valid JSON Object");
				messages.add(new ValidationMessage(data.getId(), 
						"Param 'params: " + (String)params + "' must be a String representing a valid JSON Object"));
			}
		}
		
		return (ValidationMessage[])messages.toArray(new ValidationMessage[messages.size()]);
	}

}
