/**
 * NumberUtils.java $Revision: 207 $ $Date: 2007-10-12 15:08:01 +0200 (Fri, 12 Oct 2007) $
 *
 * Copyright 2007 jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.utils.validation;


/**
 * 
 * This class contains a set of general utility methods used to 
 * work with numbers
 * 
 * @author sschz@users.sourceforge.net
 * @since 1.0
 *	
 */
public class NumberUtils {
	
	/**
	 * 
	 * It determines whether a {@link String} can be converted into an
	 * {@link Float} or not 
	 * 
	 * @param data 
	 * @return 
	 * <ul>
	 * <li>true if data is a valid float</li>
	 * <li>false if data can't be converted into a float</li>
	 * </ul>
	 * 
	 */
	public static boolean isFloat(String data) {
		
		try {
			Float.parseFloat(data);
			return true;
		} catch (NumberFormatException e) {
			return false;
		}		
	}
	
	/**
	 * 
	 * It determines whether a {@link String} can be converted into an
	 * {@link Integer} or not 
	 * 
	 * @param data 
	 * @return 
	 * <ul>
	 * <li>true if data is an integer</li>
	 * <li>false if data can't be converted into an integer</li>
	 * </ul>
	 * 
	 */
	public static boolean isInteger(String data) {

		try {
			Integer.parseInt(data);
			return true;
		} catch (NumberFormatException e) {
			return false;
		}		
	}

}
