/**
 * TagsUtils.java $Revision: 211 $ $Date: 2007-10-12 15:22:37 +0200 (Fri, 12 Oct 2007) $
 *
 * Copyright 2007 jstags
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.jstags.utils.validation;

import javax.servlet.jsp.tagext.TagData;

import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;

/**
 * 
 * This class contains a set of utility methods used to work with tags
 * and perform common operations related to them
 * 
 * @author sschz@users.sourceforge.net
 * @since 1.0
 *	
 */
public class TagsUtils {
	/**
	 * Logger for this class
	 */
	private static final Logger logger = Logger.getLogger(TagsUtils.class);
	
	/**
	 * 
	 * It determines whether a {@link String} is an EL expression or not. That
	 * is, whether it starts with "${" and ends with "}" or not.
	 * 
	 * @param value the data to be checked
	 * @return
	 * <ul>
	 * <li>true: value is an EL expression</li>
	 * <li>false: value is not an EL expression</li>
	 * </ul>
	 */
	public static boolean isELExpression(String value) {
		
		logger.debug("Checking whether " + value + " is an EL expression or not "
				+ (!StringUtils.isEmpty(value) && value.startsWith("${") && value.endsWith("}")));
		return (!StringUtils.isEmpty(value) 
				&& value.startsWith("${") 
				&& value.endsWith("}"));
	}

	/**
	 * 
	 * Determines if a certain value is available at translation time or not
	 * (in that case, it would be calculated at runtime). If the attribute value 
	 * is either {@link TagData#REQUEST_TIME_VALUE} or an EL Expression, its value 
	 * would be available only at runtime
	 * 
	 * @param value {@link Object} representing the attribute value
	 * @return
	 * <ul>
	 * <li>true: the attribute value is available at translation time. That is, it
	 * is neither an EL Expression nor {@link TagData#REQUEST_TIME_VALUE}
	 * </li>
	 * <li>false: the value is not available until runtime, that is, it is
	 * an EL Expression or {@link TagData#REQUEST_TIME_VALUE}
	 * </li>
	 * </ul>
	 * 
	 */
	public static boolean isValueAvailableAtTranslationTime(Object value) {
		
		logger.debug("Checking whether value is available at translation time or not "
				+ ((value != null) && (value != TagData.REQUEST_TIME_VALUE) && (!isELExpression((String)value))));
		
		return ((value != null)
				&& (value != TagData.REQUEST_TIME_VALUE)
				&& (!isELExpression((String)value)));
	}
}
